#!/bin/sh
INSTPATH="/opt/scriptouch-remote"
CITRIXPATH="/opt/Citrix/ICAClient"

#Test to make sure the receiver is installed.
if [ ! -d "$CITRIXPATH" ] || [ ! -f "$CITRIXPATH/config/module.ini" ]; then
    echo "Citrix Receiver doesn't appear to be installed, failing installation.";
    exit 1
fi

#Find out the architecture of the installed ICA client.
CITRIXARCH=$(file "$CITRIXPATH/wfica" | egrep -o "64-bit|32-bit" | egrep -o "64|32")

#Make a temp directory for our configuration file.
TMPDIR=$(mktemp -u -t tmp.XXXXXXXXXX)
mkdir -p "$TMPDIR"

#Change to the temporary directory and run the modifier.
cd "$TMPDIR"
cp "$INSTPATH/inimodifier" "$TMPDIR"
TMPFILE=$("$TMPDIR/inimodifier")
EXITCODE=$?

if [ "$EXITCODE" -eq "0" ]; then
    #The command executed like we expected, we should have a temp file containing
    #an updated INI file.

    #Overwrite the old Modules file with our new patched one.
    cp "$TMPDIR/$TMPFILE" "$CITRIXPATH/config/module.ini"

    #Symlink our plugin to the plugins directory.
    ln -sf "$INSTPATH/scriptouch-remote-citrix-linux-x$CITRIXARCH.so" "$CITRIXPATH/SCRIPTEL.DLL"

    #Symlink the correct architecture to the common point.
    ln -sf "$INSTPATH/scriptouch-remote-standalone-x$CITRIXARCH" "$INSTPATH/scriptouch-remote-standalone"

    #Remove our temporary files.
    rm "$TMPDIR/$TMPFILE"
    rm "$TMPDIR/inimodifier"

    #Remote our temporary directory.
    rmdir "$TMPDIR"
else
    #Something went off the rails, lets print the error message passed back to us.
    echo $TMPFILE
    exit $EXITCODE
fi

#Everything went well.
exit 0